pub struct MasterEncKeyPart(pub PublicKey);Expand description
A master encryption key part, wrapped so it can be sealed as
DiscoveryInfoResp::master_enc_key_part_sealed.
Tuple Fields
0: PublicKeyTrait Implementations
Sourceimpl Clone for MasterEncKeyPart
impl Clone for MasterEncKeyPart
Sourcefn clone(&self) -> MasterEncKeyPart
fn clone(&self) -> MasterEncKeyPart
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MasterEncKeyPart
impl Debug for MasterEncKeyPart
Sourceimpl<'de> Deserialize<'de> for MasterEncKeyPart
impl<'de> Deserialize<'de> for MasterEncKeyPart
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for MasterEncKeyPart
impl Serialize for MasterEncKeyPart
Sourceimpl Signable for MasterEncKeyPart
impl Signable for MasterEncKeyPart
const CODE: MessageCode = crate::api::MessageCode::MasterEncKeyPart
Sourceconst CONSTELLATION_BOUND: bool = false
const CONSTELLATION_BOUND: bool = false
Include a
CONSTELLATION_CLAIM in the Signed message of this type, binding the
signed message to the current Constellation.Auto Trait Implementations
impl Freeze for MasterEncKeyPart
impl RefUnwindSafe for MasterEncKeyPart
impl Send for MasterEncKeyPart
impl Sync for MasterEncKeyPart
impl Unpin for MasterEncKeyPart
impl UnsafeUnpin for MasterEncKeyPart
impl UnwindSafe for MasterEncKeyPart